package edu.usc.ict.iago.views;

import java.io.IOException;

import javax.mail.MessagingException;
import javax.servlet.ServletException;
import javax.servlet.annotation.WebServlet;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.websocket.EndpointConfig;
import javax.websocket.OnClose;
import javax.websocket.OnMessage;
import javax.websocket.OnOpen;
import javax.websocket.server.ServerEndpoint;

import edu.usc.ict.iago.agent.*;
import edu.usc.ict.iago.utils.*;


@ServerEndpoint(value = "/game/ws", configurator = GetHttpSessionConfigurator.class)
@WebServlet(name="IagoGame", loadOnStartup=1, description = "This servlet loads the Iago platform.", urlPatterns = { "/game" })
public class GameBridge extends HttpServlet  {

	/**
	 * 
	 */
	private static final long serialVersionUID = 2669425387121437625L;
		
	private GameBridgeUtils u;
	private ResourceGameSpec spec = new ResourceGameSpec(true);
	
	//private LinkedList<Event> eventQ = new LinkedList<Event>();

	public GameBridge() 
	{
		/**
		 * Sets the mail credentials for this servlet, which allows it to send email notifications.  Must be set before sending mail for each servlet.  Multiple servlets may use idendical credentials.
		 * @param user the user name, e.g., iago
		 * @param pass the password, e.g., myPassword99
		 * @param sender the sender, required for some email systems, e.g., iago@website.com
		 * @param smtpAuth if the mail server uses smtp authentication (usually true, occasionally false)
		 * @param smtpHost the smtp host, e.g., exchange.website.com
		 * @param smtpPort the smtp port, e.g., 25
		 */
		ServletUtils.setCredentials("iago", "password", "IAGO <iago@website.com>", "true", "exchange.webiste.com", "25");
		
		u = new GameBridgeUtils(spec);
	}
	
	@OnOpen
	public void onOpen(javax.websocket.Session session, EndpointConfig config) 
	{
		try {
			u.onOpenHelper(session,  config, new IAGODefaultVH( new ResourceGameSpec(false), session, new History()));
		} catch (MessagingException e) {
			e.printStackTrace();
		}
	}
	
	
	@OnClose
	public void onClose(javax.websocket.Session session, javax.websocket.CloseReason cr) {
		u.onCloseHelper(session, cr);
	}
	
	@OnMessage
	public void onMessage(javax.websocket.Session session, String msg, boolean last) 
	{
		u.onMessageHelper(session, msg, last);
	}
	
	@Override
	protected void doPost(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException 
	{		
		u.doPostHelper(request, response);
	}
	
	@Override
	protected void doGet(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException 
	{		
		u.doGetHelper(request, response);
	}
}
